/** 
 * Custom parser to parse result using Perfecto's Result API and update qTest Manager
 * Perfecto Cloud Url,Job name, Job number and securityToken must be passed as environment variable.
*/
"use strict"

var perfectoReportAPI = require('./perfecto_report_api');
const fs = require("fs");
const homeDir = require('os').homedir();
const xml2js = require('xml2js');
const parser = new xml2js.Parser({ attrkey: "ATTR" });

var getPerfectoConstants = (pathToTestResult,callBack)=>{

    var filePath = `${pathToTestResult}/PerfectoCloudInformation.xml`;

    let xml_string = fs.readFileSync(filePath, "utf8");

    parser.parseString(xml_string, function(error, result) {
        
        if(error === null) {
            return callBack(result,null);
        }
        else {
            return callBack(null,error);
        }
    });
};

module.exports.parse = (pathToTestResult) => {
    return new Promise((resolve, reject) => {
    	

        getPerfectoConstants(pathToTestResult,(perfectoData,err)=>{
            if(err){
                return reject(err);
            }else{

                var pCloudName = perfectoData['cloud.info']['perfecto.cloudname'][0];
                var pJobName = perfectoData['cloud.info']['perfecto.jobname'][0];
                var pJobNumber = process.env.JOB_INSTANCE_ID;
                var pSecurityToken =  perfectoData['cloud.info']['perfecto.securitytoken'][0];

                console.log("==============================");
                console.log(`Cloud Name:: ${pCloudName}`);
                console.log(`Job Name:: ${pJobName}`);
                console.log(`Job Number:: ${pJobNumber}`);

                var proxyHost = perfectoData['cloud.info']['local.proxy'][0]['host'][0];

                // "http://" + user + ":" + password + "@" + host + ":" + port
                var proxy = "";
                var credential = "";

                if(proxyHost !== undefined && proxyHost!==""){
                    var protocol = perfectoData['cloud.info']['local.proxy'][0]['protocol'][0];
                    if(protocol === undefined || protocol ===""){
                        protocol = "http";
                    }
                    var username = perfectoData['cloud.info']['local.proxy'][0]['username'][0];
                    if(username !== undefined && username!==""){
                        var password = perfectoData['cloud.info']['local.proxy'][0]['password'][0];
                        if(password !== undefined && password!==""){
                            credential = `${username}:${password}@`;
                        }
                    }

                    proxy = `${protocol}://${credential}${proxyHost}`;

                    console.log(`Proxy used:: ${proxy}`);
                    
                }else{
                    console.log("Proxy used:: None");
                }

                console.log("==============================");

                if (pCloudName === undefined || pCloudName === ""){
                    return reject("Please provide Perfecto Cloud URL as env variable - PERFECTO_CLOUD_URL");
                }else{
                    if (pJobName === undefined || pJobName === ""){
                        return reject("Please provide Perfecto Job Name as env variable - PERFECTO_JOB_NAME");
                    }else{
                        if (pJobNumber === undefined || pJobNumber === ""){
                            return reject("Please provide Perfecto Job Number as env variable - PERFECTO_JOB_NUMBER");
                        }else{
                            if (pSecurityToken === undefined || pSecurityToken === ""){
                                return reject("Please provide Perfecto Security Token as env variable - PERFECTO_SECURITY_TOKEN");
                            }else{
                                return perfectoReportAPI.getPerfectoResultAPI(proxy,pCloudName,pJobName,pJobNumber,pSecurityToken,resolve,reject);
                            }
                        }
                    }
                }
            }

        });

        
    });
}