"use strict"
var request = require("request");

var converter = (body,callBack) =>{
	
	var resultsArray = [];

	var objResult = JSON.parse(body);

	var resources = objResult.resources;

	var automationContent="";

	for(var orderIndex = 0; orderIndex < resources.length; orderIndex++){
	try{
	  let resultMap = new Map();

	  var resource = resources[orderIndex];

	  automationContent=undefined;
	  
	  var platforms = resource.platforms;

	  resultMap["name"]=resource.name;
	  // console.log(resources.name);

	  switch(resource.status) {
  		case "PASSED":
  			resultMap["status"]= "PASS";
  			break;
  		case "FAILED":

  			resultMap["status"]= "FAIL";
  			break;
  		default:
  			resultMap["status"]= "SKIP";
  	  }

	  // console.log(resources.status);
   	  var startDate = new Date(resource.startTime);
   	  resultMap["exe_start_date"]=startDate.toISOString();
   	  // console.log(startDate.toISOString());

      var endDate = new Date(resource.endTime);
      resultMap["exe_end_date"]=endDate.toISOString();
   	  // console.log(endDate.toISOString());

      resultMap["order"]=resources.length - orderIndex;
      // console.log(resources.length - orderIndex);

      var customFields = resource.customFields;

      var customField;
	  
	  	for(var customFieldIndex = 0; customFieldIndex < customFields.length; customFieldIndex++){
	  		customField = customFields[customFieldIndex];
	  		automationContent=customField.automation_content;
	  		if(automationContent){
	  			break;
	  		}
	  	}

	  	if(automationContent===undefined || automationContent===""){
	  		automationContent=resource.name;
	  	}

	  	for(var indexPlatform = 0;indexPlatform<platforms.length;indexPlatform++){
	  		var platform = platforms[indexPlatform];
	  		automationContent = `${automationContent}$${platform.deviceType} - ${platform.os}`;
	  		if(platform.browserInfo){
	  			if(platform.browserInfo.browserType){
	  				automationContent = `${automationContent} - ${platform.browserInfo.browserType}`
		  		}else{
		  			if(platform.mobileInfo){
		  				automationContent = `${automationContent} - Mobile Browser`
		  			}
		  		}
	  		}
	  		
	  	}

	  	resultMap["automation_content"]=automationContent;

	  	var testLogs = [];

	  	// Test failure message
	  	if(resource.status!=="PASSED"){

	  		var errMess ="No Failure message provided!";
	  		if(resource.message){
	  			errMess = resource.message;
	  		}

	  		var failureMessage = createLogEntry("FAIL","Failure Message",errMess);
	  		testLogs.push(failureMessage);
	  	}

	  	// Perfecto Report URL
	  	var reportUrlInfo = createLogEntry("PASS","Perfecto Report URL",`<a href="${resource.reportURL}" target="_blank">${resource.reportURL}</a>`);
	  	testLogs.push(reportUrlInfo);

     	// Device Type

     	// Adding steps log
	  	resultMap["test_step_logs"] = testLogs;

      resultsArray.push(resultMap);

  }catch(err){
  	console.log(">>>>>>>>> " + err);
  }
	  
	  // console.log("=========================");
	}

	
	return callBack(resultsArray);
};

var createLogEntry = (status,expected_result,actual_result)=>{

  	var logEntry = {};
  	logEntry.status = status;
 	logEntry.description = expected_result;
 	logEntry.expected_result = expected_result;
 	logEntry.actual_result = actual_result;
 	return logEntry;
}

module.exports.getPerfectoResultAPI = (proxy,pCloudName,pJobName,pJobNumber,pSecurityToken,resolve,reject) =>{

	var options = { 
		'method': 'GET',
		'proxy':proxy,
  		'url': `https://${pCloudName}.reporting.perfectomobile.com/export/api/v1/test-executions`,
  		'qs': { 'jobName[0]': pJobName, 'jobNumber[0]': pJobNumber },
		'headers': { 'PERFECTO_AUTHORIZATION': pSecurityToken} 
 	};

 	request(options, function (error, response, body) {
	  if (error){
	  	return reject(error);
	  }else{
	  	return converter(body,resolve);
	  } 
	});
}